@@ -15,20 +15,16 @@ class IControlpanel(Interface):
     )  # noqa
 
     def add(names):
-        """ Create controlpanel children by names
-        """
+        """Create controlpanel children by names"""
 
     def get(names):
-        """ Read controlpanel children by names
-        """
+        """Read controlpanel children by names"""
 
     def update(names):
-        """ Update controlpanel children by names
-        """
+        """Update controlpanel children by names"""
 
     def delete(names):
-        """ Remove controlpanel children by names
-        """
+        """Remove controlpanel children by names"""
 
 
 class IDexterityTypesControlpanel(IControlpanel):
