@@ -238,7 +238,7 @@ class TestSearchFunctional(unittest.TestCase):
         response = self.api_session.get("/@search", params=query)
 
         first_item = response.json()["items"][0]
-        self.assertDictContainsSubset(
+        self.assertLessEqual(
             {
                 u"@id": self.portal_url + u"/folder/doc",
                 u"Creator": u"test_user_1_",
@@ -267,15 +267,14 @@ class TestSearchFunctional(unittest.TestCase):
                 u"last_comment_date": None,
                 u"listCreators": [u"test_user_1_"],
                 u"location": None,
-                u"meta_type": u"Dexterity Item",
                 u"portal_type": u"DXTestDocument",
                 u"review_state": u"private",
                 u"start": u"1950-01-01T00:00:00+00:00",
                 u"sync_uid": None,
                 u"title": u"Lorem Ipsum",
                 u"total_comments": 0,
-            },
-            first_item,
+            }.items(),
+            first_item.items(),
         )
         # This value changed in Plone 5.2
         # (Dexterity gained support for getObjSize)
@@ -419,8 +418,14 @@ class TestSearchFunctional(unittest.TestCase):
         response = self.api_session.get("/@search", params=query)
 
         self.assertEqual(
-            [u"/plone/folder", u"/plone/folder/doc", u"/plone/folder/other-document"],
-            result_paths(response.json()),
+            sorted(
+                [
+                    u"/plone/folder",
+                    u"/plone/folder/doc",
+                    u"/plone/folder/other-document",
+                ]
+            ),
+            sorted(result_paths(response.json())),
         )
 
     def test_extended_path_index_query_multiple(self):
@@ -434,14 +439,16 @@ class TestSearchFunctional(unittest.TestCase):
         response = self.api_session.get("/@search", params=query)
 
         self.assertEqual(
-            [
-                u"/plone/folder",
-                u"/plone/folder/doc",
-                u"/plone/folder/other-document",
-                u"/plone/folder2",
-                u"/plone/folder2/doc",
-            ],
-            result_paths(response.json()),
+            sorted(
+                [
+                    u"/plone/folder",
+                    u"/plone/folder/doc",
+                    u"/plone/folder/other-document",
+                    u"/plone/folder2",
+                    u"/plone/folder2/doc",
+                ]
+            ),
+            sorted(result_paths(response.json())),
         )
 
         # path as a dict with a query list
@@ -454,14 +461,16 @@ class TestSearchFunctional(unittest.TestCase):
         response = self.api_session.get("/@search", params=query)
 
         self.assertEqual(
-            [
-                u"/plone/folder",
-                u"/plone/folder/doc",
-                u"/plone/folder/other-document",
-                u"/plone/folder2",
-                u"/plone/folder2/doc",
-            ],
-            result_paths(response.json()),
+            sorted(
+                [
+                    u"/plone/folder",
+                    u"/plone/folder/doc",
+                    u"/plone/folder/other-document",
+                    u"/plone/folder2",
+                    u"/plone/folder2/doc",
+                ]
+            ),
+            sorted(result_paths(response.json())),
         )
 
     def test_extended_path_index_depth_limiting(self):
